STM32F103C8T6_WIFI_Heating_system

Dependencies:   mbed mbed-STM32F103C8T6 eeprom_flash Watchdog PinDetect DS1820

  1. Bluepill STM32F103C8T6 Heating system
    1. _This project is core part of bigger heating system project!_

Features - Reading temperature from four DS18B20 sensors - Making a decision about switching on/off heater and pomp - Executing simple user commands from UART - Storing state parameters to program memory (EEPROM emulation)

Revision:
50:94730b99ea41
Parent:
46:0d60fbcfb245
Child:
58:70930f201f97
--- a/temp_controller/temp_controller.h	Sun Sep 23 19:59:48 2018 +0000
+++ b/temp_controller/temp_controller.h	Mon Sep 24 13:47:03 2018 +0000
@@ -15,7 +15,8 @@
 void start_temp();                              // start temp conversion
 void check_temp();                              // check temp sensor state and read temp
 void process_temp();                            // process heating algorithm
-unsigned int get_temp_config_value();           // get config value from EEPROM 
+unsigned int get_temp_config_value();           // get config value from EEPROM
+unsigned int get_mode_config_value();           // get mode value from EEPROM 
 void save_new_config();                         // save new config to EEPROM
 void set_pomp_and_heater_by(float * work_temp); // sets state of pomp and heater depends on input temp
 void set_pomp_and_heater_eco_mode(float * work_temp); // sets state of pomp and heater depends on input temp